
/***************************************************************************
 *                    aKpi - a QT/KDE acpi frontend                        *
 *                                                                         *
 *   file:              acpibase.h                                         *
 *   copyright:         (c) 2002 by Tom Winkler                            *
 *   email:             akpi@aon.at                                        *
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ACPIBASE_H

	#define ACPIBASE_H

	#include <qobject.h>
	#include <qstring.h>
	#include <qdir.h>
	#include <qfile.h>
	#include <qtextstream.h>
	#include <qptrlist.h>
	#include <qmap.h>
	#include <qdict.h>
	#include <qlistview.h>
	#include <qnamespace.h>

	#include <qhbox.h>

	#include <iostream>

	#include "config.h"
	#include "acpidata.h"
	#include "configfile.h"
	#include "tools.h"

	class AcpiList;  // forward declaration

	// defines to format output of print methods
	#define INDENT_MULT 2
	#define INDENT_ADD 2


	class AcpiBase : public QHBox, public QListViewItem {

		Q_OBJECT

		private:
			void seekLine(int line, QFile &file, QTextStream &stream);
			QMap<int, QString> loadFile(QString fileName);

		protected:
	 		typedef QDict<AcpiData> typFileItem;  // represents a line within an acpi- file (strLineKey -> AcpiData)
			typedef QDict<typFileItem> typFile;   // represents a acpi-file (strFileName -> typFileItem)
			typedef QMap<QString, QMap<QString, bool> > typKnownFile;  // represents known (static) acpi-file items (filename, key, polling)
			typFile files;                        // file dictionary
			typKnownFile knownFiles;              // known files map
			QList<AcpiBase> children;             // list of children (subdirectories)
			QList<QListViewItem> lvitems;         // list of ListViewItems for files (filenames; not key->val)
			QString name;
			QString path;
			AcpiList* list;                       // pointer to acpilist object
			void parseFiles(QString path);
			void parseData(QString path, QString filename);
			QString indent(int iIndent);
			QWidget* wparent;
			QHBox* hbox;

		public:
			enum pollTypes { all, battery, processor, acadapter, thermal, toshiba, none };
			pollTypes pollType;
			AcpiBase(AcpiList* list, QWidget* wparent, QListView* lvparent);
			AcpiBase(AcpiList* list, QWidget* wparent, QListViewItem* lvparent);
			~AcpiBase();
			void parseDir(QString basepath, QString path);
			void poll(pollTypes type);
			void event();  // to be implemented sometimes in the future...
			virtual void emitSignals();
			virtual void updateGUI();
			void print(int indent);

		public slots:
			void sltUpdateAll() { poll(all); emitSignals(); updateGUI(); }
	};

#endif // ACPIBASE_H


