
#include "acpibattery.h"

using namespace std;

// ------------------------------------------------------------
// AcpiBattery::AcpiBattery
// ------------------------------------------------------------
AcpiBattery::AcpiBattery(AcpiList* list, QWidget* wparent, QListViewItem* lvparent) : AcpiBase(list, wparent, lvparent)
{
	this->list->listBattery.append(this);
	name = "AcpiBattery";
	pollType = battery;
	hbox = static_cast<QHBox*>(this);

	absolute = true;
	useColors = false;

	number = this->list->listBattery.count();

	char buffer[2];
	sprintf (buffer, "%d", number);
	lbBattery = new QLabel(QString("Battery ") + buffer + ": " , hbox, "lbBattery", 0);
	lbBattery->adjustSize();
	lbPresent = new QLabel("", hbox, "lbPresent", 0);
	lbPresent->adjustSize();

	pgBar = new QProgressBar(100, hbox, "pgBar", 0);
	pgBar->setFixedWidth(100);
	pgBar->setProgress(0);
	pgBar->setCenterIndicator(true);

	hbox->adjustSize();
	hbox->show();	


	QMap <QString, bool> info;
	info.insert("design capacity", false);
	info.insert("last full capacity", false);
	info.insert("battery technology", false);
	info.insert("design voltage", false);
	info.insert("design capacity warning", false);
	info.insert("design capacity low", false);
	info.insert("capacity granularity 1", false);
	info.insert("capacity granularity 2", false);
	info.insert("model number", false);
	info.insert("serial number", false);
	info.insert("battery type", false);
	info.insert("OEM info", false);
	knownFiles.insert("info" , info);
}


// ------------------------------------------------------------
// AcpiBattery::~AcpiBattery
// ------------------------------------------------------------
AcpiBattery::~AcpiBattery()
{
	delete pgBar;
	delete lbBattery;
	delete lbPresent;
}


// ------------------------------------------------------------
// AcpiBattery::emitSignals
// ------------------------------------------------------------
void AcpiBattery::emitSignals()
{
	AcpiData* design = (*files["info"])["design capacity"];
	AcpiData* lastFull = (*files["info"])["last full capacity"];
	AcpiData* remaining = (*files["state"])["remaining capacity"];
	AcpiData* present = (*files["info"])["present"];

	if (present->getValue() == "yes" && design != NULL && remaining != NULL) {
		if (absolute) {
/* QT3 code
			emit sgnBattery(number, double(atoi(remaining->getValue().section(' ', 0, 0)))
				/ (double(atoi(design->getValue().section(' ', 0, 0))) / 100.0));
*/

			emit sgnBattery(number, double(atoi((strtok(const_cast<char*>(remaining->getValue().latin1()), " ") )))
				/ (double(atoi(  strtok(const_cast<char*>(design->getValue().latin1()), "")  )) / 100.0));


		} else {
/* QT3 code
			emit sgnBattery(number, double(atoi(remaining->getValue().section(' ', 0, 0)))
				/ (double(atoi(lastFull->getValue().section(' ', 0, 0))) / 100.0));
*/

			emit sgnBattery(number, double(atoi((  strtok(const_cast<char*>(remaining->getValue().latin1()), " ") )))
				/ (double(atoi(   strtok(const_cast<char*>(lastFull->getValue().latin1()), "") )) / 100.0));

		}
	} else {
		emit sgnBattery(number, -1);  // -1 means that the battery is not present or the values are invalid
	}

	AcpiBase* node;
	for (node = children.first(); node != 0; node = children.next()) {
  	node->emitSignals();
	}
}


// ------------------------------------------------------------
// AcpiBattery::updateGUI
// ------------------------------------------------------------
void AcpiBattery::updateGUI()
{
	AcpiData* design = (*files["info"])["design capacity"];
	AcpiData* lastFull = (*files["info"])["last full capacity"];
	AcpiData* remaining = (*files["state"])["remaining capacity"];
	AcpiData* present = (*files["info"])["present"];

	if (present->getValue() == "yes" && design != NULL && remaining != NULL) {

		int progress;

		if (absolute) {
/* Qt3 code
			progress = int(double(atoi(remaining->getValue().section(' ', 0, 0)))
				/ (double(atoi(design->getValue().section(' ', 0, 0)))) / 100.0));
*/
			progress = int(double(atoi(strtok(const_cast<char*>(remaining->getValue().latin1()), " ")))
				/ (double(atoi(strtok(const_cast<char*>(design->getValue().latin1()), " ")))) * 100.0);

#ifdef ACPI_DEBUG
			cout << "BATTERY (" << path << ") remaining: " << remaining->getValue() << endl;
			cout << "BATTERY (" << path << ") design: " << lastFull->getValue() << endl;
#endif
		} else {
/* QT3 code
			progress = int(double(atoi(remaining->getValue().section(' ', 0, 0)))
				/ (double(atoi(lastFull->getValue().section(' ', 0, 0)))) / 100.0));
*/

			progress = int(double(atoi(strtok(const_cast<char*>(remaining->getValue().latin1()), " ")))
				/ (double(atoi(strtok(const_cast<char*>(lastFull->getValue().latin1()), " ")))) * 100.0);
#ifdef ACPI_DEBUG
			cout << "BATTERY (" << path << ") remaining: " << remaining->getValue() << endl;
			cout << "BATTERY (" << path << ") lastFull: " << lastFull->getValue() << endl;
#endif
		}

		QColor highcolor;

		if (useColors) {
			if (progress <= 10) {
				highcolor = QColor(170, 40, 40);   // red
			} else if (progress <= 20) {
				highcolor = QColor(225, 225, 40);  // yellow
			} else {
				highcolor = QColor(30, 120, 45);   // green
			}
		} else {
			highcolor = QColor(10, 70, 100);     // blue
		}

		QPalette pal = pgBar->palette();
		pal.setColor(QColorGroup::Highlight, highcolor);
		pgBar->setPalette(pal);

		pgBar->setProgress(progress);
		pgBar->show();
		lbPresent->hide();

  } else {
		pgBar->hide();
		lbPresent->setText("absent");
		lbPresent->show();
	}

	AcpiBase* node;
	for (node = children.first(); node != 0; node = children.next()) {
  	node->updateGUI();
	}
}


// ------------------------------------------------------------
// AcpiBattery::sltBatCalc
// ------------------------------------------------------------
void AcpiBattery::sltBatCalc(bool absolute)
{
//	cout << "sltBatClac(" << absolute << ")" << endl;
	this->absolute = absolute;
	ConfigFile cfg(tools::getCfgFile());
	cfg.setValue(QString("battery_calc_absolute"), QString(tools::bool2str(absolute)));
	cfg.commitFile();
	emitSignals();
	updateGUI();
}


// ------------------------------------------------------------
// AcpiBattery::sltUseColors
// ------------------------------------------------------------
void AcpiBattery::sltUseColors(bool useColors)
{
//	cout << "sltUseColors(" << tools::bool2str(useColors) << ")" << endl;
	this->useColors = useColors;
	ConfigFile cfg(tools::getCfgFile());
	cfg.setValue(QString("battery_use_colors"), QString(tools::bool2str(useColors)));
	cfg.commitFile();
	updateGUI();
}
