
#include "acpitoshiba.h"


// ------------------------------------------------------------
// AcpiToshiba::AcpiToshiba
// ------------------------------------------------------------
AcpiToshiba::AcpiToshiba(AcpiList* list, QWidget* wparent, QListViewItem* lvparent, QString path) : AcpiBase(list, wparent, lvparent)
{
	this->path = path;
	this->list->listToshiba.append(this);
	name = "AcpiToshiba";
	pollType = toshiba;
	hbox = static_cast<QHBox*>(this);
	vboxL = new QVBox(hbox, "vboxL", 0);
	vboxR = new QVBox(hbox, "vboxR", 0);

	number = this->list->listToshiba.count();

	char buffer[2];
	sprintf (buffer, "%d", number);
	lbToshiba = new QLabel(QString("Toshiba ") + buffer + ":           ", vboxL, "lbToshiba", 0);
	lbDriver = new QLabel(QString("  Driver v") + "?", vboxL, "lbDriver", 0);
	lbProcInt = new QLabel(QString("  Proc_int v") + "?", vboxL, "lbProcInt", 0);

	hboxLCD = new QHBox(vboxR, "hboxLCD", 0);
	lbBrightness = new QLabel(QString("LCD Brightness:"), hboxLCD, "lbBrightness", 0);
    sbLCD = new QScrollBar(	0, 7,                       // range
    						1, 1,                       // line/page steps
							4,                           // inital value
							QScrollBar::Horizontal,      // orientation
							hboxLCD, "sbLCD" );

	hboxCpad = new QHBox(vboxR, "hboxCpad", 0);
	lbSensitivity = new QLabel(QString("cPad Sensitivity:"), hboxCpad, "lbSensitivity", 0);
    sbCpad = new QScrollBar(	0, 255,                       // range
    						1, 10,                       // line/page steps
							48,                           // inital value
							QScrollBar::Horizontal,      // orientation
							hboxCpad, "sbCpad" );

	hboxFan = new QHBox(vboxR, "hboxFan", 0);
	lbFanRunning = new QLabel(QString("Fan: running=") + "?", hboxFan, "lbFanRunning", 0);
	cbForceOn = new QCheckBox(QString("force on"), hboxFan, "cbForceOn");

	hboxVideo = new QHBox(vboxR, "hboxVideo", 0);
	cbLCDOut = new QCheckBox(QString("LCD Out"), hboxVideo, "cbLCDOut");
	cbCRTOut = new QCheckBox(QString("CRT Out"), hboxVideo, "cbCRTOut");
	cbTVOut = new QCheckBox(QString("TV Out"), hboxVideo, "cbTVOut");

	lbKeys = new QLabel(QString("Hotkeys: hotkey_ready=") + "?" + " hotkey=" + "?", vboxR, "lbKeys", 0);

	QObject::connect(sbLCD, SIGNAL(valueChanged(int)), this, SLOT(sltSetBrightness(int)));
	QObject::connect(sbCpad, SIGNAL(valueChanged(int)), this, SLOT(sltSetSensitivity(int)));
	QObject::connect(cbForceOn, SIGNAL(toggled(bool)), this, SLOT(sltSetFan(bool)));

	hbox->adjustSize();
	hbox->show();
}


// ------------------------------------------------------------
// AcpiToshiba::~AcpiToshiba
// ------------------------------------------------------------
AcpiToshiba::~AcpiToshiba()
{

}


// ------------------------------------------------------------
// AcpiToshiba::emitSignals
// ------------------------------------------------------------
void AcpiToshiba::emitSignals()
{
/*
	AcpiData* state = (*files["state"])["state"];

	if (state->getValue() == "on-line") {
		emit sgnOnline(true);
	AcpiData* running = (*files["fan"])["running"];
	AcpiData* force_on = (*files["fan"])["force_on"];
	AcpiData* brightness = (*files["lcd"])["brightness"];
	AcpiData* brightness_levels = (*files["lcd"])["brightness_levels"];
	AcpiData* lcd_out = (*files["video"])["lcd_out"];
	AcpiData* crt_out = (*files["video"])["crt_out"];
	AcpiData* tv_out = (*files["video"])["tv_out"];
	AcpiData* hotkey_ready = (*files["keys"])["hotkey_ready"];
	AcpiData* hotkey = (*files["keys"])["hotkey"];

	char buffer[2];
	sprintf (buffer, "%d", number);
	lbToshiba->setText(QString("Toshiba ") + buffer + ": " + "Driver v" + driver->getValue() + " Proc_int v" + proc
	} else {
		emit sgnOnline(false);
	}
*/

	AcpiBase* node;
	for (node = children.first(); node != 0; node = children.next()) {
  	node->emitSignals();
	}
}


// ------------------------------------------------------------
// AcpiToshiba::updateGUI
// ------------------------------------------------------------
void AcpiToshiba::updateGUI()
{

	AcpiData* driver = (*files["version"])["driver"];
	AcpiData* proc_int = (*files["version"])["proc_interface"];
	AcpiData* running = (*files["fan"])["running"];
	AcpiData* force_on = (*files["fan"])["force_on"];
	AcpiData* brightness = (*files["lcd"])["brightness"];
//	AcpiData* brightness_levels = (*files["lcd"])["brightness_levels"];
	AcpiData* lcd_out = (*files["video"])["lcd_out"];
	AcpiData* crt_out = (*files["video"])["crt_out"];
	AcpiData* tv_out = (*files["video"])["tv_out"];
	AcpiData* hotkey_ready = (*files["keys"])["hotkey_ready"];
	AcpiData* hotkey = (*files["keys"])["hotkey"];

	char buffer[2];
	sprintf (buffer, "%d", number);
	lbToshiba->setText(QString("Toshiba ") + buffer + ":           ");
	lbDriver->setText(QString("  Driver v") + driver->getValue());
	lbProcInt->setText(QString("  Proc_int v") + proc_int->getValue());
	lbFanRunning->setText(QString("Fan: running=") + running->getValue());
	cbForceOn->setChecked(atoi(force_on->getValue()));
	sbLCD->setValue(atoi(brightness->getValue()));
	cbLCDOut->setChecked(atoi(lcd_out->getValue()));
	cbCRTOut->setChecked(atoi(crt_out->getValue()));
	cbTVOut->setChecked(atoi(tv_out->getValue()));
	lbKeys->setText(QString("Hotkeys: hotkey_ready=") + hotkey_ready->getValue() + " hotkey=" + hotkey->getValue());

	AcpiBase* node;
	for (node = children.first(); node != 0; node = children.next()) {
  		node->updateGUI();
	}
}

//----------------------------------------------------------------
// AcpiToshiba::sltSetBrightness
//----------------------------------------------------------------
#include <stdio.h>
#include <err.h>
void AcpiToshiba::sltSetBrightness(int val)
{
	char		cmd_strs[2][16], *argv[3];

	strcpy(cmd_strs[0], "lcd");
	sprintf(cmd_strs[1], "%d", val);
	argv[0] = cmd_strs[0];
	argv[1] = cmd_strs[1];
	argv[2]=0;
	tools::execProg(2, argv);
}

//----------------------------------------------------------------
// AcpiToshiba::sltSetSensitivity
//----------------------------------------------------------------
#include <stdio.h>
#include <err.h>
void AcpiToshiba::sltSetSensitivity(int val)
{
	char		cmd_strs[2][16], *argv[3];

	strcpy(cmd_strs[0], "cpad");
	sprintf(cmd_strs[1], "%d", val);
	argv[0] = cmd_strs[0];
	argv[1] = cmd_strs[1];
	argv[2]=0;
	tools::execProg(2, argv);
}

//----------------------------------------------------------------
// AcpiToshiba::sltSetFan
//----------------------------------------------------------------
void AcpiToshiba::sltSetFan(bool on)
{
	char		cmd_strs[2][16], *argv[3];

	strcpy(cmd_strs[0], "fan");
	if ( on == TRUE )
		sprintf(cmd_strs[1], "on");
	else
		sprintf(cmd_strs[1], "auto");
	argv[0] = cmd_strs[0];
	argv[1] = cmd_strs[1];
	argv[2]=0;
	tools::execProg(2, argv);
}

//----------------------------------------------------------------
// AcpiToshiba::sltSetLCD
//----------------------------------------------------------------
void AcpiToshiba::sltSetLCD(bool on)
{
	char		cmd_strs[3][16], *argv[4];

	strcpy(cmd_strs[0], "video");
	strcpy(cmd_strs[1], "lcd");
	if ( on == TRUE )
		sprintf(cmd_strs[2], "on");
	else
		sprintf(cmd_strs[2], "off");
	argv[0] = cmd_strs[0];
	argv[1] = cmd_strs[1];
	argv[2] = cmd_strs[2];
	argv[3]=0;
	tools::execProg(3, argv);
}

//----------------------------------------------------------------
// AcpiToshiba::sltSetCRT
//----------------------------------------------------------------
void AcpiToshiba::sltSetCRT(bool on)
{
	char		cmd_strs[3][16], *argv[4];

	strcpy(cmd_strs[0], "video");
	strcpy(cmd_strs[1], "crt");
	if ( on == TRUE )
		sprintf(cmd_strs[2], "on");
	else
		sprintf(cmd_strs[2], "off");
	argv[0] = cmd_strs[0];
	argv[1] = cmd_strs[1];
	argv[2] = cmd_strs[2];
	argv[3]=0;
	tools::execProg(3, argv);
}

//----------------------------------------------------------------
// AcpiToshiba::sltSetTV
//----------------------------------------------------------------
void AcpiToshiba::sltSetTV(bool on)
{
	char		cmd_strs[3][16], *argv[4];

	strcpy(cmd_strs[0], "video");
	strcpy(cmd_strs[1], "tv");
	if ( on == TRUE )
		sprintf(cmd_strs[2], "on");
	else
		sprintf(cmd_strs[2], "off");
	argv[0] = cmd_strs[0];
	argv[1] = cmd_strs[1];
	argv[2] = cmd_strs[2];
	argv[3]=0;
	tools::execProg(3, argv);
}

