
/***************************************************************************
 *                      aKpi - a KDE acpi frontend                         *
 *                                                                         *
 *   file:              configfile.cpp                                     *
 *   copyright:         (c) 2002 by Tom Winkler                            *
 *   email:             akpi@aon.at                                        *
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "configfile.h"


// ------------------------------------------------------------
// ConfigFile::ConfigFile
// ------------------------------------------------------------
ConfigFile::ConfigFile()
{
	changed = false;
}


// ------------------------------------------------------------
// ConfigFile::ConfigFile
// ------------------------------------------------------------
ConfigFile::ConfigFile(QString fileName)
{
	changed = false;
	readFile(fileName);
}


// ------------------------------------------------------------
// ConfigFile::~ConfigFile
// ------------------------------------------------------------
ConfigFile::~ConfigFile()
{

}


// ------------------------------------------------------------
// ConfigFile::readFile
// ------------------------------------------------------------
void ConfigFile::readFile(QString fileName)
{
	int separator;

	this->fileName = fileName;

	QString linebuffer, key, val;
	QFile file(fileName);
	QTextStream filestream(&file);

	if (file.open(IO_ReadOnly)) {
		while (!filestream.eof()) {
			linebuffer = filestream.readLine();

			separator = linebuffer.find(QString("="), 0, false);

			if (separator != -1) {
				key = (linebuffer.left(separator)).stripWhiteSpace();
				val = (linebuffer.mid(++separator)).stripWhiteSpace();
				map[key] = val;
			}

		}
		file.close();
	}
}


// ------------------------------------------------------------
// ConfigFile::commitFile
// ------------------------------------------------------------
void ConfigFile::commitFile()
{
	if (changed) {
		QFile file(fileName);
		QTextStream filestream(&file);

		if (file.open(IO_WriteOnly)) {
			QMap<QString, QString>::Iterator it;
				for(it = map.begin(); it != map.end(); ++it) {
					filestream << it.key() << "=" << it.data() << endl;
				}
			file.close();
		}	
	}
}


// ------------------------------------------------------------
// ConfigFile::exists
// ------------------------------------------------------------
bool ConfigFile::exists(QString fileName)
{
	QFile file(fileName);
	bool retVal = file.open(IO_ReadOnly);
	if (retVal) file.close();
	return retVal;
}


// ------------------------------------------------------------
// ConfigFile::getValue
// ------------------------------------------------------------
QString ConfigFile::getValue(QString key)
{
	if (map.contains(key)) {
		return map[key];
	} else {
		return QString("");
	}
}


// ------------------------------------------------------------
// ConfigFile::setValue
// ------------------------------------------------------------
void ConfigFile::setValue(QString key, QString val, bool overwrite)
{
	if ((map.contains(key) && overwrite) || !map.contains(key)) {
		map[key] = val;
		changed = true;
	}
}
