#include "configwidget.h"


// ------------------------------------------------------------
// ConfigWidget::ConfigWidget
// ------------------------------------------------------------
ConfigWidget::ConfigWidget(QWidget* parent, const char* name) : QWidget(parent, name)
{
	int rows = 0;
	int cols = 0;
	grid = new QGridLayout(this, 4, 0, 5, 5);

	hbPolling = new QHBox(this);
	lbPolling = new QLabel("polling interval: ", hbPolling);
	lbPolling->adjustSize();
	spinPolling = new QSpinBox(1, 999, 1, hbPolling, "spinPolling");
	spinPolling->adjustSize();
	lbPollingSec = new QLabel(" sec", hbPolling);
	lbPollingSec->adjustSize();
	grid->addWidget(hbPolling, rows++, cols, AlignTop | AlignLeft);

	hbBatCalc = new QHBox(this);
	bgBatCalc = new QVButtonGroup("battery calculation mode:", hbBatCalc);
	rdBatCalcAbs = new QRadioButton("absolute (real)", bgBatCalc, "rdBatCalcRel");
	rdBatCalcAbs->adjustSize();
	rdBatCalcRel = new QRadioButton("relative", bgBatCalc, "rdBatCalcRel");
	rdBatCalcRel->adjustSize();
	QString ttip = "Choosing \"absolute\" will calculate current battery capacity\n";
	ttip += "with respect to the design capacity of the battery.\n";
	ttip += "Choosing \"relative\" will calculate the battery capacity\n";
	ttip += "with respect to the last full capacity of the battery.\n";
	ttip += "Please note that typical batteries don't reach their full\n";
	ttip += "design capacity anymore if they are getting older or are not\n";
	ttip += "fully discharged from time to time. Because of that the \"absolute\"\n";
	ttip += "setting might never show a 100% full state for such batteries.";
	QToolTip::add(hbBatCalc, ttip);
	grid->addWidget(hbBatCalc, rows++, cols, AlignTop | AlignLeft);

	static QHBox hbColorPGBar(this);
	cbColorPGBar = new QCheckBox("use colors (red, yellow, green)\nfor battery states in MainWindow", &hbColorPGBar);
	grid->addWidget(&hbColorPGBar, rows++, cols, AlignTop | AlignLeft);

	static QHBox hbColorTray(this);
	cbColorTray = new QCheckBox("use colors (red, yellow, green)\nfor battery states in TrayBar", &hbColorTray);
	grid->addWidget(&hbColorTray, rows++, cols, AlignTop | AlignLeft);

	grid->setRowStretch(--rows, 100);

	// pass on signals of private members to the outside
	QObject::connect(spinPolling, SIGNAL(valueChanged(int)), this, SIGNAL(sgnPolling(int)));
	QObject::connect(rdBatCalcAbs, SIGNAL(toggled(bool)), this, SIGNAL(sgnBatCalc(bool)));
	QObject::connect(cbColorPGBar, SIGNAL(toggled(bool)), this, SIGNAL(sgnColorPGBar(bool)));
	QObject::connect(cbColorTray, SIGNAL(toggled(bool)), this, SIGNAL(sgnColorTray(bool)));
}


// ------------------------------------------------------------
// ConfigWidget::~ConfigWidget
// ------------------------------------------------------------
ConfigWidget::~ConfigWidget()
{
	delete lbPolling;
	delete lbPollingSec;
	delete spinPolling;
	delete hbPolling;
	delete rdBatCalcAbs;
	delete rdBatCalcRel;
	delete bgBatCalc;
	delete hbBatCalc;
	delete cbColorPGBar;
	delete cbColorTray;
	delete grid;
}


// ------------------------------------------------------------
// ConfigWidget::sltPolling
// ------------------------------------------------------------
void ConfigWidget::sltPolling(int interval)
{
	spinPolling->setValue(interval); 	
}


// ------------------------------------------------------------
// ConfigWidget::sltCalc
// ------------------------------------------------------------
void ConfigWidget::sltCalc(bool absolute)
{
	rdBatCalcAbs->setChecked(absolute);
	rdBatCalcRel->setChecked(!absolute);
}


// ------------------------------------------------------------
// ConfigWidget::sltColorPGBar
// ------------------------------------------------------------
void ConfigWidget::sltColorPGBar(bool useColor)
{
	cbColorPGBar->setChecked(useColor);
}


// ------------------------------------------------------------
// ConfigWidget::sltColorTray
// ------------------------------------------------------------
void ConfigWidget::sltColorTray(bool useColor)
{
	cbColorTray->setChecked(useColor);
}

