
/***************************************************************************
 *                      aKpi - a KDE acpi frontend                         *
 *                                                                         *
 *   file:              main.cpp                                           *
 *   copyright:         (c) 2002 by Tom Winkler                            *
 *   email:             akpi@aon.at                                        *
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <iostream>

#include <qapplication.h>
//#include <qwindowsstyle.h>
#include <qmap.h>
#include <qstring.h>
#include <qfile.h>

#include <kwin.h>
#include <kapp.h>
#include <kcmdlineargs.h>

#include "settings.h"
#include "mainwidget.h"
#include "traywidget.h"
#include "acpibase.h"
#include "acpiroot.h"
#include "acpilist.h"
#include "msghandler.h"
#include "browserwidget.h"
#include "tabwidget.h"
#include "aboutwidget.h"
#include "configwidget.h"
#include "configfile.h"
#include "tools.h"

using namespace std;

// ------------------------------------------------------------
// main
// ------------------------------------------------------------
/*!
	This is the main method of aKpi. All important objects are created here. Futhermore this
	method initiates several checks such as paths, config file and last but not least the
	command to parse ACPI_DIR is given from here.
*/
int main(int argc, char** argv)
{
	// check if compiled-in paths are correct
	if (!tools::validPaths()) return -1;

	// check if there is a config file (if not, one is created)
	tools::createCfgFile();

	// read config file
	ConfigFile cfg(tools::getCfgFile());
	#ifdef KDE
	  KApplication* app    = new  KApplication(argc, argv , "aKpi");
	#else
		QApplication* app    = new QApplication(argc, argv);
	#endif
	MainWidget* main       = new MainWidget();
	TrayWidget* tray       = new TrayWidget(0, 0, tools::getImgPath() + TRAY_IMG);
	AcpiList* list         = new AcpiList();
	BrowserWidget* browser = new BrowserWidget();
	TabWidget* tab         = new TabWidget();
	ConfigWidget* config   = new ConfigWidget();
	AboutWidget* about     = new AboutWidget();
	AcpiRoot* tree         = new AcpiRoot(list, main, browser->listview);
	MsgHandler* handler    = new MsgHandler(app, main, tray, browser, tree, list, tab, about, config);

	tree->parseDir("", ACPI_ROOT);
	#ifdef ACPI_DEBUG
		cout << endl << " --- --- --- s t a r t   o f   t r e e (internal datastructure) --- --- --- " << endl << endl;
		tree->print(INDENT_ADD * 2);
		cout << endl << " --- --- --- e n d   o f   t r e e --- --- --- " << endl;
	#endif

	handler->createConnections();
	handler->sltTimer(atoi(cfg.getValue("polling_interval")));
	handler->initGUI();
	tree->sltUpdateAll();
	tray->show();
	tab->addTab(main, "Status");
	tab->addTab(config, "Configuration");
	tab->addTab(about, "About");
	tab->resize(250, 300);
	main->setCaption("aKpi");
	app->setMainWidget(tray);

	int retVal = app->exec(); 	// pass control to the Qt Application object

	delete handler;
	delete tree;
	delete about;
//	delete config;
//	delete tab;
	delete browser;
	delete list;
//	delete tray;
	delete main;
	delete app;

	return retVal;
}
