
#include "msghandler.h"


// ------------------------------------------------------------
//MsgHandler::MsgHandler
// ------------------------------------------------------------
MsgHandler::MsgHandler(QApplication* app, MainWidget* main, TrayWidget* tray, BrowserWidget* browser, AcpiBase* tree, AcpiList* list, TabWidget* tab, AboutWidget* about, ConfigWidget* config)
{
	this->app      = app;
	this->main     = main;
	this->tray     = tray;
	this->browser  = browser;
	this->tree     = tree;
	this->list     = list;
	this->tab      = tab;
	this->about    = about;
	this->config   = config;
	timer          = new QTimer();
}


// ------------------------------------------------------------
//MsgHandler::MsgHandler
// ------------------------------------------------------------
MsgHandler::~MsgHandler()
{
	delete timer;
}


// ------------------------------------------------------------
// MsgHandler::createConnections();
// ------------------------------------------------------------
void MsgHandler::createConnections()
{
	AcpiBase* node;

	// connect ac-adapter signals with the matching slots
	for (node = list->listACAdapter.first(); node != 0; node = list->listACAdapter.next()) {
		QObject::connect(node, SIGNAL(sgnOnline(bool)), tray, SLOT(sltOnline(bool)));
		main->addWidget(static_cast<QHBox*>(node));
	}

	// connect battery signals with the matching slots
	for (node = list->listBattery.first(); node != 0; node = list->listBattery.next()) {
		QObject::connect(node, SIGNAL(sgnBattery(int, double)), tray, SLOT(sltBattery(int, double)));
		QObject::connect(config, SIGNAL(sgnBatCalc(bool)), node, SLOT(sltBatCalc(bool)));  // configWidget abs vs. rel
		QObject::connect(config, SIGNAL(sgnColorPGBar(bool)), node, SLOT(sltUseColors(bool)));
		QObject::connect(this, SIGNAL(sgnBatCalc(bool)), node, SLOT(sltBatCalc(bool)));  // init abs vs. rel
		main->addWidget(dynamic_cast<QHBox*>(node));
	}

	// absolute vs. realtive fill state calculation
		QObject::connect(this, SIGNAL(sgnBatCalc(bool)), config, SLOT(sltCalc(bool)));

		QObject::connect(this, SIGNAL(sgnColorPGBar(bool)), config, SLOT(sltColorPGBar(bool)));


// tray colors
		QObject::connect(config, SIGNAL(sgnColorTray(bool)), tray, SLOT(sltUseColors(bool)));
		QObject::connect(this, SIGNAL(sgnColorTray(bool)), config, SLOT(sltColorTray(bool)));
		QObject::connect(this, SIGNAL(sgnColorTray(bool)), tray, SLOT(sltUseColors(bool)));


  
	// colors for battery fill state in MainWindow

	// connect thermal signals with the matching slots
	for (node = list->listThermal.first(); node != 0; node = list->listThermal.next()) {
		main->addWidget(dynamic_cast<QHBox*>(node));
	}

	// connect Toshiba signals with the matching slots
	for (node = list->listToshiba.first(); node != 0; node = list->listToshiba.next()) {
		main->addWidget(dynamic_cast<QHBox*>(node));
	}

	// polling
	QObject::connect(this, SIGNAL(sgnPolling(int)), config, SLOT(sltPolling(int)));
	QObject::connect(config, SIGNAL(sgnPolling(int)), this, SLOT(sltTimer(int)));

	// timer device for polling
	QObject::connect(timer, SIGNAL(timeout()), tree, SLOT(sltUpdateAll()));

	// main message
	QObject::connect(tray, SIGNAL(sgnMain()), tab, SLOT(show()));

	// browser message
	QObject::connect(tray, SIGNAL(sgnBrowser()), browser, SLOT(show()));

	// quit message
	QObject::connect(tray, SIGNAL(sgnQuit()), app, SLOT(quit()));
}


// ------------------------------------------------------------
// MsgHandler::initGUI
// ------------------------------------------------------------
void MsgHandler::initGUI()
{
	ConfigFile cfg(tools::getCfgFile());
	emit sgnPolling(atoi(cfg.getValue("polling_interval")));
	emit sgnBatCalc(tools::str2bool(cfg.getValue("battery_calc_absolute")));
	emit sgnColorPGBar(tools::str2bool(cfg.getValue("battery_use_colors")));
	emit sgnColorTray(tools::str2bool(cfg.getValue("battery_tray_use_colors")));
}


// ------------------------------------------------------------
// MsgHandler::sltTimer
// ------------------------------------------------------------
void MsgHandler::sltTimer(int interval)
{
	ConfigFile cfg(tools::getCfgFile());
	cfg.setValue(QString("polling_interval"), QString(tools::itoa(interval)));
	cfg.commitFile();
	if (timer->isActive()) {
		timer->stop();  	
	}
	timer->start(interval * 1000, false);	
}
