
/***************************************************************************
 *                      aKpi - a KDE acpi frontend                         *
 *                                                                         *
 *   file:              tools.cpp                                          *
 *   copyright:         (c) 2002 by Tom Winkler                            *
 *   email:             akpi@aon.at                                        *
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#include "tools.h"

using namespace std;


// ------------------------------------------------------------
// getCfgFile
// ------------------------------------------------------------
/*!
	This method returns the path and filename of the main config-file
*/
QString tools::getCfgFile()
{
	return QString(QDir::homeDirPath() + "/" + CFG_FILE);
/*
	QString cfgFile = getenv("HOME");
	if (cfgFile.right(1) != "/") {
		cfgFile.append("/");   	
	}
	cfgFile.append(CFG_FILE);

	return cfgFile;
*/
}
 	

// ------------------------------------------------------------
// validPaths
// ------------------------------------------------------------
/*!
	This method checks if the compiled in paths for the images are valid or not. If
	they are not, a warning message is printed and the application terminates.
*/
bool tools::validPaths()
{
	unsigned int i;
	bool retVal;
	QFile file;
	QMap<int, QString> map;	

	map[0] = getImgPath() + TRAY_IMG;
	map[1] = getImgPath() + AC_IMG;
	map[2] = getImgPath() + AKPI_IMG;
	map[3] = ACPI_ROOT;

	retVal = true;

	for (i = 0; i < map.count(); i++) {
		if (!file.exists(map[i])) {
			retVal = false;
			break;
		}
		// cout << "found: " << map[i] << endl;
	}

	if (!retVal) {
		cout << "missing file " << map[i] << endl;
		cout << "terminating" << endl;
	}

	return retVal;
}


// ------------------------------------------------------------
// createCfgFile
// ------------------------------------------------------------
/*!
	This method creates the main config file that contains all the (default) values that are
	part of the Map map. If the config file already exists only new key/value pairs will be
	added.
*/
void tools::createCfgFile()
{
	ConfigFile cfg(getCfgFile());

	QMap<QString, QString> map;	
	map["polling_interval"] = "20";
	map["battery_calc_absolute"] = "true";
	map["battery_use_colors"] = "true";

	QMap<QString, QString>::Iterator it;
	for(it = map.begin(); it != map.end(); ++it) {
		cfg.setValue(it.key(), it.data(), false);
	}
	cfg.commitFile();
}


// ------------------------------------------------------------
// itoa
// ------------------------------------------------------------
/*!
	This method returns a char array for the given int.
*/
char* tools::itoa(int number)
{
	// This implementation is not perfect (and I'm very well aware of that fact) but it does the job...
	static char buffer[25];
	sprintf(buffer, "%d", number);
	return buffer;
}


// ------------------------------------------------------------
// str2bool
// ------------------------------------------------------------
/*!
 This method returns the bool value for the given string value.
*/
bool tools::str2bool(QString sVal)
{
	if (sVal.lower() == "true")
		return true;
	else
		return false;
}


// ------------------------------------------------------------
// bool2str
// ------------------------------------------------------------
/*!
 This method returns the string value for the given bool value.
*/
QString tools::bool2str(bool bVal)
{
	if (bVal == true)
		return "true";
	else
		return "false";
}


//--------------------------------------------------------------
// execProg
//--------------------------------------------------------------
/*!
 This method executes a child process and waits for it to return.
*/
void tools::execProg(int argc, char *argv[])
{
	switch(fork()) {
		case -1:                  // We were unable to create child process.
			warn("fork error");
			return;

		case 0:                   // We are the new child process.
			execvp(argv[0], argv);  // If we return from this call, something went wrong.
			warn("exec error");     // So, flag the error and exit.
			exit(-1);

		default:                  // We are the parent.
			if(wait(NULL) == -1)
				warn("wait error");
	}

	argc = 0;  // just for now to make gcc happy
}


//--------------------------------------------------------------
// getDataPath
//--------------------------------------------------------------
/*!
	This method returns the aKpi data Path.
*/
QString tools::getDataPath()
{
	KStandardDirs StdDirs;
	return StdDirs.findDirs("data", "akpi").first();
}


//--------------------------------------------------------------
// getImgPath
//--------------------------------------------------------------
/*!
	This method returns the aKpi data Path.
*/
QString tools::getImgPath()
{
	return getDataPath() + "pics/";
}
