#include "traywidget.h"


// ------------------------------------------------------------
// TrayWidget::TrayWidget
// ------------------------------------------------------------
#ifdef KDE
	TrayWidget::TrayWidget(QWidget* parent, const char* name, QString image) : KSystemTray(parent, name)
#else
	TrayWidget::TrayWidget(QWidget* parent, const char* name, QString image) : QWidget(parent, name)
#endif
{
	percent = 0;
	online = false;

	useColors = false;

	pixmap = new QPixmap(image);
	pixmapAC = new QPixmap(tools::getImgPath() + AC_IMG);
	painter = new QPainter(pixmap);
	painterAC = new QPainter(pixmapAC);
	lbBattery = new QLabelExt("", this, "lbBattery", 0);
	lbBattery->setPixmap(*pixmap);
	QToolTip::add(this, "0%");
	this->adjustSize();

	popup = new QPopupMenu(this);

	popup->insertItem("Main-Window", this, SLOT(sltMain()));
	popup->insertItem("Browser", this, SLOT(sltBrowser()));
	popup->insertSeparator();
	popup->insertItem("Quit", this, SLOT(sltQuit()));
	popup->insertTearOffHandle();

	connect(lbBattery, SIGNAL(sgnMousePress(QMouseEvent*)), this, SLOT(sltPopup(QMouseEvent*)));
}


// ------------------------------------------------------------
// TrayWidget::~TrayWidget
// ------------------------------------------------------------
TrayWidget::~TrayWidget()
{
	delete lbBattery;
	delete painter;
	delete pixmap;
	delete pixmapAC;
}


// ------------------------------------------------------------
// TrayWidget::sltBattery
// ------------------------------------------------------------
void TrayWidget::sltBattery(int number, double percent)
{
	int count = 0;
	this->percent = 0;

	mapBattery[number] = percent;

	QMap<int, double>::Iterator it;
	for(it = mapBattery.begin(); it != mapBattery.end(); ++it) {
		if (it.data() != -1) {
			this->percent += it.data();
			++count;
		}
//		cout << "TrayWidget::mapBattery    key:" << it.key() << " data:" << it.data() << endl;
	}

	if (count != 0) {
		this->percent /= count;
	} else {
		this->percent = 0;
	}
	
	drawBattery();
}


// ------------------------------------------------------------
// TrayWidget::sltACPower
// ------------------------------------------------------------
void TrayWidget::sltOnline(bool online)
{
	this->online = online;
	drawBattery();
}


// ------------------------------------------------------------
// TrayWidget::drawBattery
// ------------------------------------------------------------
void TrayWidget::drawBattery()
{
	double dblScaled = (percent / (100.0/15.0));
	int scaled = int(dblScaled);


	QColor highcolor;

	if (useColors) {
		if (percent <= 10) {
			highcolor = QColor(170, 40, 40);   // red
		} else if (percent <= 20) {
			highcolor = QColor(200, 200, 40);  // yellow
		} else {
			highcolor = QColor(45, 130, 50);   // green
		}
	} else {
		highcolor = QColor(0, 25, 200);      // blue
	}

 
	painter->fillRect(7, 16, 10, -15, QColor(197, 194, 255));
	painter->fillRect(7, 16, 10, -scaled, highcolor); //QColor(0, 25, 200));
	if (online) {
		painterAC->fillRect(7, 16, 10, -15, QColor(0, 25, 200));
		painterAC->fillRect(7, 16, 10, -scaled, QColor(197, 194, 255));
		bitBlt(pixmap, 0, 0, pixmapAC, 0, 0, 20, 24, Qt::XorROP, false);
	}
	lbBattery->setPixmap(*pixmap);
	QToolTip::remove(this);
	char buffer[4];
	sprintf (buffer, "%d", (int)percent);
	QToolTip::add(this, QString(buffer) + "%");
}



// ------------------------------------------------------------
// TrayWidget::sltPopup
// ------------------------------------------------------------
void TrayWidget::sltPopup(QMouseEvent* event)
{
	QSize size = popup->sizeHint();
 	popup->popup(QPoint(event->globalX() - size.width() + 20, event->globalY() - size.height()));
}


// ------------------------------------------------------------
// TrayWidget::sltUseColors
// ------------------------------------------------------------
void TrayWidget::sltUseColors(bool useColors)
{
//	cout << "sltUseColors(" << tools::bool2str(useColors) << ")" << endl;
	this->useColors = useColors;
	ConfigFile cfg(tools::getCfgFile());
	cfg.setValue(QString("battery_tray_use_colors"), QString(tools::bool2str(useColors)));
	cfg.commitFile();
	drawBattery();
}
